# manifoldconfig.py - Data handling routines developed by Optibrium for integration with the Manifold API
# Use of this code is subject to the terms of the StarDrop License Agreement and use, copying or redistribution of this file for use by other persons or organisations is prohibited
# Copyright(C) Optibrium Ltd 2023
# stardrop-support@optibrium.com
#

"""Module to hold some configuration options for accessing Manifold
from StarDrop"""
import logging
import zlib

version = "Manifold Version 1.0"

# post urls for the manifold API
FAST_SCORE_BATCH_POST_URL = "https://api.postera.ai/api/v1/synthetic-accessibility/fast-score/batch/"
FAST_SCORE_POST_URL = "https://api.postera.ai/api/v1/synthetic-accessibility/fast-score/"
RETROSYNTHESIS_POST_URL = "https://api.postera.ai/api/v1/synthetic-accessibility/retrosynthesis/batch/"

# parameters for the logging of the program
LOGGING_LEVEL = logging.INFO
LOGGER_FILE = "manifold_logs.txt"


def get_token():
    """Attempt to read a saved token
    @returns: A string token it available, otherwise an empty string
    """
    try:
        with open('manifoldtoken.txt', 'rb') as f:
            token = zlib.decompress(f.read()).decode()
            return token
    except Exception as e:
        logging.basicConfig(filename=LOGGER_FILE)
        logging.error(e)
        pass
    return ''


def set_token(token):
    """Save a token for future use.
    @param: token: The new token
    """
    try:
        with open('manifoldtoken.txt', 'wb') as f:
            f.write(zlib.compress(token.encode()))
    except Exception as e:
        logging.basicConfig(filename=LOGGER_FILE)
        logging.error(e)
        pass
